Tutorials
=========

For more information on Jupyter itself, see `their web site <https://jupyter.org/>`_.

.. toctree::
   :caption: Basic tutorials
   :maxdepth: 1

   notebooks/plotting
   notebooks/calibration